import { defineStore } from 'pinia';
import { api } from '@flaschengeist/api';
import { Notify } from 'quasar';

export const usePricelistStore = defineStore({
  id: 'pricelist_old',
  state: () => ({
    prices: [] as FG.Price[],
    drinkTypes: [] as FG.DrinkType[],
  }),
  getters: {},
  actions: {
    async getDrinkTypes(force = false) {
      if (force || this.drinkTypes.length == 0) {
        try {
          const { data } = await api.get<FG.DrinkType[]>('/pricelist_old/drink_type');
          this.drinkTypes = data;
        } catch (error) {
          throw error;
        }
      }
      return this.drinkTypes;
    },
    async setDrinkType(name: String) {
      try {
        const { data } = await api.post<FG.DrinkType>('/pricelist_old/drink_type', { name });
        this.drinkTypes.push(data);
      } catch (error) {
        throw error;
      }
      return this.drinkTypes;
    },
    async modifyDrinkType(drink_type: FG.DrinkType) {
      try {
        const { data } = await api.put<FG.DrinkType>(
          `/pricelist_old/drink_type/${drink_type.id}`,
          drink_type
        );
        const idx = this.drinkTypes.findIndex(({ id }) => id == drink_type.id);
        if (idx >= 0) {
          this.drinkTypes[idx] = data;
        }
      } catch (error) {
        Notify.create({
          type: 'negative',
          message: 'Getränkeart konnte nicht geändert werden',
        });
        throw error;
      }
    },
    async deleteDrinkType(drink_type: FG.DrinkType) {
      try {
        await api.delete(`/pricelist_old/drink_type/${drink_type.id}`);
        const idx = this.drinkTypes.findIndex(({ id }) => id == drink_type.id);
        if (idx >= 0) {
          this.drinkTypes.splice(idx, 1);
        }
      } catch (error) {
        Notify.create({
          type: 'negative',
          message: 'Getränkeart konnte nicht gelöscht werden!',
        });
        throw error;
      }
    },
    async getPrices(force = false) {
      if (force || this.prices.length == 0) {
        try {
          const { data } = await api.get<FG.Price[]>('/pricelist_old/price');
          this.prices = data;
        } catch (error) {
          throw error;
        }
      }
      return this.prices;
    },
    async set_price(price: FG.Price) {
      try {
        const { data } = await api.post<FG.Price>('/pricelist_old/price', {
          ...price,
          drink_type_id: price.drink_type.id,
        });
        console.log(data);
        this.prices.push(data);
      } catch (error) {
        Notify.create({
          type: 'negative',
          message: 'Getränk konnte nicht angelegt werden.',
        });
        throw error;
      }
    },
    async modify_price(price: FG.Price) {
      try {
        const { data } = await api.put<FG.Price>(`/pricelist_old/price/${price.id}`, {
          ...price,
          drink_type_id: price.drink_type.id,
        });
        const idx = this.prices.findIndex(({ id }) => id == price.id);
        if (idx >= 0) {
          this.prices[idx] = data;
        }
      } catch (error) {
        Notify.create({
          type: 'negative',
          message: 'Getränk konnte nicht geändert werden',
        });
        throw error;
      }
    },
    async delete_price(price: FG.Price) {
      try {
        await api.delete(`/pricelist_old/price/${price.id}`);
        const idx = this.prices.findIndex(({ id }) => id == price.id);
        if (idx >= 0) {
          this.prices.splice(idx, 1);
        }
      } catch (error) {
        Notify.create({
          type: 'negative',
          message: 'Getränk konnte nicht gelöscht werden!',
        });
        throw error;
      }
    },
  },
});
